TeXBox

Enum TeXBox 

pub enum TeXBox<ET: EngineTypes> {
    V {
        info: VBoxInfo<ET>,
        children: Box<[VNode<ET>]>,
        start: SourceRef<ET>,
        end: SourceRef<ET>,
    },
    H {
        info: HBoxInfo<ET>,
        children: Box<[HNode<ET>]>,
        start: SourceRef<ET>,
        end: SourceRef<ET>,
        preskip: Option<Skip<ET::Dim>>,
    },
}
A box, i.e. the result of e.g. \hbox, \vbox, \vtop, a line of a paragraph, a row/cell in an \halign

Variants



V

A vertial box

Fields

info: VBoxInfo<ET>

The box info, containing “metadata” about the box

children: Box<[VNode<ET>]>

The nodes in this box

start: SourceRef<ET>

The source reference of the start of this box

end: SourceRef<ET>

The source reference of the end of this box



H

A horizontal box

Fields

info: HBoxInfo<ET>

The box info, containing “metadata” about the box

children: Box<[HNode<ET>]>

The nodes in this box

start: SourceRef<ET>

The source reference of the start of this box

end: SourceRef<ET>

The source reference of the end of this box

preskip: Option<Skip<ET::Dim>>

The vertical skip before this box, if any, as computed based on \prevdepth

Implementations

Source

impl<ET: EngineTypes> TeXBox<ET>

pub fn to_math(self) -> MathNode<ET, UnresolvedMathFontStyle<ET>>

pub fn is_empty(&self) -> bool

Whether this box is empty

pub fn assign_height(&mut self, h: ET::Dim)

Assigns the given height to this box (as e.g. \ht0=50pt)

pub fn assigned_height(&self) -> Option<ET::Dim>

The assigned height of this box, if any (i.e. the result of \ht0=...)

pub fn assign_width(&mut self, w: ET::Dim)

Assigns the given width to this box (as e.g. \wd0=50pt)

pub fn assigned_width(&self) -> Option<ET::Dim>

The assigned width of this box, if any (i.e. the result of \wd0=...)

pub fn assign_depth(&mut self, d: ET::Dim)

Assigns the given depth to this box (as e.g. \dp0=50pt)

pub fn assigned_depth(&self) -> Option<ET::Dim>

The assigned depth of this box, if any (i.e. the result of \dp0=...)

pub fn to_or_scaled(&self) -> ToOrSpread<ET::Dim>

The “scaling factor” of this box, i.e. the to or spread in e.g. \hbox to 50pt or \hbox spread 10pt