pub enum TeXBox<ET: EngineTypes> {
V {
info: VBoxInfo<ET>,
children: Box<[VNode<ET>]>,
start: SourceRef<ET>,
end: SourceRef<ET>,
},
H {
info: HBoxInfo<ET>,
children: Box<[HNode<ET>]>,
start: SourceRef<ET>,
end: SourceRef<ET>,
preskip: Option<Skip<ET::Dim>>,
},
}Expand description
A box, i.e. the result of e.g. \hbox, \vbox, \vtop,
a line of a paragraph, a row/cell in an \halign…
Variants
Implementations
Sourceimpl<ET: EngineTypes> TeXBox<ET>
impl<ET: EngineTypes> TeXBox<ET>
pub fn to_math(self) -> MathNode<ET, UnresolvedMathFontStyle<ET>>
Sourcepub fn assign_height(&mut self, h: ET::Dim)
pub fn assign_height(&mut self, h: ET::Dim)
Assigns the given height to this box (as e.g. \ht0=50pt)
Sourcepub fn assigned_height(&self) -> Option<ET::Dim>
pub fn assigned_height(&self) -> Option<ET::Dim>
The assigned height of this box, if any (i.e. the result of \ht0=...)
Sourcepub fn assign_width(&mut self, w: ET::Dim)
pub fn assign_width(&mut self, w: ET::Dim)
Assigns the given width to this box (as e.g. \wd0=50pt)
Sourcepub fn assigned_width(&self) -> Option<ET::Dim>
pub fn assigned_width(&self) -> Option<ET::Dim>
The assigned width of this box, if any (i.e. the result of \wd0=...)
Sourcepub fn assign_depth(&mut self, d: ET::Dim)
pub fn assign_depth(&mut self, d: ET::Dim)
Assigns the given depth to this box (as e.g. \dp0=50pt)
Sourcepub fn assigned_depth(&self) -> Option<ET::Dim>
pub fn assigned_depth(&self) -> Option<ET::Dim>
The assigned depth of this box, if any (i.e. the result of \dp0=...)
Sourcepub fn to_or_scaled(&self) -> ToOrSpread<ET::Dim>
pub fn to_or_scaled(&self) -> ToOrSpread<ET::Dim>
The “scaling factor” of this box, i.e. the to or spread in e.g. \hbox to 50pt or \hbox spread 10pt